@@ -2,7 +2,9 @@ from __future__ import annotations
 
 import pytest
 
-import dask
+pytest.register_assert_rewrite(
+    "dask.array.utils", "dask.dataframe.utils", "dask.bag.utils"
+)
 
 # The doctests in these files fail due to either:
 # - Non-required dependencies not being installed
@@ -54,38 +56,51 @@ except ImportError:
 
 def pytest_addoption(parser):
     parser.addoption("--runslow", action="store_true", help="run slow tests")
+    parser.addoption("--runarrayexpr", action="store_true", help="run array-expr tests")
 
 
 def pytest_runtest_setup(item):
     if "slow" in item.keywords and not item.config.getoption("--runslow"):
         pytest.skip("need --runslow option to run")
+    if "array_expr" in item.keywords and not item.config.getoption("--runarrayexpr"):
+        pytest.skip("need --runarrayexpr option to run")
+    elif "array_expr" not in item.keywords and item.config.getoption("--runarrayexpr"):
+        if "normal_and_array_expr" not in item.keywords:
+            pytest.skip("only array-expr tests are being run")
 
 
-skip_with_pyarrow_strings = pytest.mark.skipif(
-    bool(dask.config.get("dataframe.convert-string")),
-    reason="No need to run with pyarrow strings",
-)
+def pytest_assertrepr_compare(op, left, right):
+    import difflib
 
-xfail_with_pyarrow_strings = pytest.mark.xfail(
-    bool(dask.config.get("dataframe.convert-string")),
-    reason="Known failure with pyarrow strings",
-)
+    from dask._task_spec import Task
+
+    if isinstance(left, Task) and isinstance(right, Task):
+
+        def _get_attrs(node):
+            return (
+                [
+                    str(node.func),
+                ]
+                + sorted([str(a) for a in node.args])
+                + sorted([f"{k}: {v}" for k, v in node.kwargs.items()])
+            )
+
+        diff = list(
+            difflib.ndiff(
+                _get_attrs(left),
+                _get_attrs(right),
+            )
+        )
+        return [
+            "Comparing two dask graph nodes:",
+            f" left: {left.key} right: {right.key}",
+            " Diff:",
+        ] + diff
 
 
-def pytest_collection_modifyitems(config, items):
-    for item in items:
-        if "skip_with_pyarrow_strings" in item.keywords:
-            item.add_marker(skip_with_pyarrow_strings)
-        if "xfail_with_pyarrow_strings" in item.keywords:
-            item.add_marker(xfail_with_pyarrow_strings)
+@pytest.fixture(autouse=True, scope="session")
+def allow_distributed_async_clients():
+    import dask
 
-
-pytest.register_assert_rewrite(
-    "dask.array.utils", "dask.dataframe.utils", "dask.bag.utils"
-)
-
-
-@pytest.fixture(params=["disk", "tasks"])
-def shuffle_method(request):
-    with dask.config.set({"dataframe.shuffle.method": request.param}):
-        yield request.param
+    with dask.config.set({"admin.async-client-fallback": "sync"}):
+        yield
