@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 from random import randint
 from time import time
 
@@ -15,7 +17,7 @@ nrepetitions = 1
 
 
 def trivial(width, height):
-    """ Embarrassingly parallel dask """
+    """Embarrassingly parallel dask"""
     d = {("x", 0, i): i for i in range(width)}
     for j in range(1, height):
         d.update({("x", j, i): (noop, ("x", j - 1, i)) for i in range(width)})
@@ -23,7 +25,7 @@ def trivial(width, height):
 
 
 def crosstalk(width, height, connections):
-    """ Natural looking dask with some inter-connections """
+    """Natural looking dask with some inter-connections"""
     d = {("x", 0, i): i for i in range(width)}
     for j in range(1, height):
         d.update(
@@ -39,7 +41,7 @@ def crosstalk(width, height, connections):
 
 
 def dense(width, height):
-    """ Full barriers between each step """
+    """Full barriers between each step"""
     d = {("x", 0, i): i for i in range(width)}
     for j in range(1, height):
         d.update(
@@ -55,7 +57,7 @@ import numpy as np
 
 x = np.logspace(0, 4, 10)
 trivial_results = dict()
-for get in [dask.get, threaded.get, local.get_sync, multiprocessing.get]:
+for get in (dask.get, threaded.get, local.get_sync, multiprocessing.get):
     y = list()
     for n in x:
         dsk, keys = trivial(int(n), 5)
@@ -74,9 +76,9 @@ f, (left, right) = plt.subplots(
     nrows=1, ncols=2, sharex=True, figsize=(12, 5), squeeze=True
 )
 
-for get in trivial_results:
-    left.loglog(x * 5, trivial_results[get], label=get.__module__)
-    right.loglog(x * 5, trivial_results[get] / x, label=get.__module__)
+for get, result in trivial_results.items():
+    left.loglog(x * 5, result, label=get.__module__)
+    right.loglog(x * 5, result / x, label=get.__module__)
 
 left.set_title("Cost for Entire graph")
 right.set_title("Cost per task")
@@ -94,7 +96,7 @@ plt.savefig("images/scaling-nodes.png")
 
 x = np.linspace(1, 100, 10)
 crosstalk_results = dict()
-for get in [threaded.get, local.get_sync]:
+for get in [threaded.get, local.get_sync]:  # type: ignore[assignment]
     y = list()
     for n in x:
         dsk, keys = crosstalk(1000, 5, int(n))
@@ -112,9 +114,9 @@ f, (left, right) = plt.subplots(
     nrows=1, ncols=2, sharex=True, figsize=(12, 5), squeeze=True
 )
 
-for get in crosstalk_results:
-    left.plot(x, crosstalk_results[get], label=get.__module__)
-    right.semilogy(x, crosstalk_results[get] / 5000.0 / x, label=get.__module__)
+for get, result in crosstalk_results.items():
+    left.plot(x, result, label=get.__module__)
+    right.semilogy(x, result / 5000.0 / x, label=get.__module__)
 
 left.set_title("Cost for Entire graph")
 right.set_title("Cost per edge")
